Welcome to myproject's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2
   
   install
   deployment

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

